#[non_exhaustive]pub enum AgentBuildError {
Tool(ToolRegistrationError),
Route(AgentRegistrationError),
CallableNameCollision(String),
EmptyName,
ZeroMaxTurns,
Retrieval(RetrievalError),
}Expand description
Failure while assembling an Agent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Tool(ToolRegistrationError)
Tool registration failed.
Route(AgentRegistrationError)
Child Agent route registration failed.
CallableNameCollision(String)
One model-facing name was used by both a Tool and an Agent.
EmptyName
The Agent name is blank.
ZeroMaxTurns
The configured turn limit cannot execute any model turn.
Retrieval(RetrievalError)
A static or dynamic context registration was invalid.