#[non_exhaustive]pub enum ConversationSummarizerError {
Run(AgentError),
Encode(Error),
InvalidPassLimit,
InvalidOutput,
}Expand description
Failure produced before a summary can be committed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Run(AgentError)
The configured summarizer Agent failed through its canonical execution path.
Encode(Error)
Canonical transcript data could not be encoded for the summary request.
InvalidPassLimit
Automatic compaction pass limit was outside the supported range.
InvalidOutput
The summarizer returned an unusable summary.