#[non_exhaustive]pub enum GatewayErrorKind {
NotFound,
InvalidInput,
CapabilityDenied,
AuthorityEscalation,
MaxDepth,
BudgetExceeded,
Cancelled,
DeadlineExceeded,
ChildFailed,
PolicyDenied,
ObservabilityFailed,
}Expand description
Normalized gateway failure category.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
The requested route is not registered.
InvalidInput
The delegation input did not match the canonical schema.
CapabilityDenied
The parent was not granted the agent capability.
AuthorityEscalation
The configured child grant would amplify parent authority.
MaxDepth
The configured delegation-depth bound was reached.
BudgetExceeded
The shared run-tree budget rejected the delegation.
Cancelled
Delegated work was cancelled.
DeadlineExceeded
Delegated work exceeded its effective deadline.
ChildFailed
The child agent failed without violating a hard runtime invariant.
PolicyDenied
Gateway middleware or policy denied the delegation.
ObservabilityFailed
The configured journal rejected a gateway event.