#[non_exhaustive]pub enum StructuredAgentError {
Agent(AgentError),
Output(StructuredOutputError),
}Expand description
Failure while executing or locally decoding a typed Agent run.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Agent(AgentError)
Canonical Agent execution failed.
Output(StructuredOutputError)
The terminal response did not satisfy the bound Rust output type.