#[non_exhaustive]pub enum TerminalReviewError {
InvalidConfiguration(String),
RequestTooLarge {
bytes: usize,
maximum: usize,
},
Execution(String),
InvalidVerdict(String),
}Expand description
Failure while evaluating a terminal candidate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidConfiguration(String)
Reviewer configuration is invalid.
RequestTooLarge
The transcript and candidate exceed the reviewer request boundary.
Execution(String)
The reviewer could not execute or obtain a decision.
InvalidVerdict(String)
A reviewer returned an unsafe or malformed decision.