#[non_exhaustive]pub enum ToolErrorPolicy {
ReturnToModel,
FailFast,
}Expand description
How the agent handles tool failures that are safe for model recovery.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReturnToModel
Return safe execution failures to the model as failed tool results.
FailFast
Stop the agent immediately on every tool error.