#[non_exhaustive]pub enum TurnReviewScope {
IntermediateOnly,
EveryModelResponse,
}Expand description
Model responses selected for internal turn review.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IntermediateOnly
Review tool plans and provider continuation responses, but leave the final response to the independently configured terminal reviewer.
EveryModelResponse
Review every model response, including the final response.