pub struct AgentDescriptor {
pub id: CapabilityId,
pub name: String,
pub version: String,
pub description: String,
pub risk: RiskLevel,
pub metadata: BTreeMap<String, Value>,
}Expand description
Versioned contract for invoking an agent through a gateway.
Fields
id: CapabilityIdStable capability identity.
name: StringModel-facing delegation name.
version: StringSemantic contract version.
description: StringModel-facing description of when this agent should be used.
risk: RiskLevelCoarse risk classification for policy engines.
metadata: BTreeMap<String, Value>Host-only namespaced metadata.
Implementations
Sourceimpl AgentDescriptor
impl AgentDescriptor
Sourcepub fn new(name: impl Into<String>, description: impl Into<String>) -> Self
pub fn new(name: impl Into<String>, description: impl Into<String>) -> Self
Creates an agent contract with the canonical delegation schema.
Sourcepub fn capability(&self) -> CapabilityDescriptor
pub fn capability(&self) -> CapabilityDescriptor
Converts this descriptor into a grantable agent capability.
Sourcepub fn model_spec(&self) -> ToolSpec
pub fn model_spec(&self) -> ToolSpec
Converts this descriptor into the callable shape exposed to a model.